@@ -27,11 +27,11 @@ class EigenValuesAssistant : public Cantor::Assistant
 {
   public:
     EigenValuesAssistant( QObject* parent, QList<QVariant> args );
-    ~EigenValuesAssistant() override;
+    ~EigenValuesAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
     
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
     
 };
 
