@@ -27,11 +27,11 @@ class InvertMatrixAssistant : public Cantor::Assistant
 {
   public:
     InvertMatrixAssistant( QObject* parent, QList<QVariant> args );
-    ~InvertMatrixAssistant() override;
+    ~InvertMatrixAssistant() override = default;
 
-    void initActions() Q_DECL_OVERRIDE;
+    void initActions() override;
     
-    QStringList run(QWidget* parentt) Q_DECL_OVERRIDE;
+    QStringList run(QWidget* parentt) override;
     
 };
 
