@@ -73,10 +73,6 @@ BackendChooseDialog::BackendChooseDialog(QWidget* parent) : QDialog(parent)
     connect(this, &BackendChooseDialog::accepted, this, &BackendChooseDialog::onAccept);
 }
 
-BackendChooseDialog::~BackendChooseDialog()
-{
-}
-
 void BackendChooseDialog::onAccept()
 {
     m_backend=m_ui.backendList->currentItem()->text();
@@ -89,8 +85,13 @@ void BackendChooseDialog::onAccept()
 
 void BackendChooseDialog::updateDescription()
 {
-    Cantor::Backend* current=Cantor::Backend::createBackend( m_ui.backendList->currentItem()->text() );
-    m_ui.descriptionView->setHtml(i18n(BackendChooseDialog::descriptionTemplate, current->name(), current->description(), current->url(), current->version()));
+    Cantor::Backend* current=Cantor::Backend::getBackend( m_ui.backendList->currentItem()->text() );
+    if (current)
+    {
+        const QString& desc = i18n(BackendChooseDialog::descriptionTemplate,
+                                   current->name(), current->description(), current->url(), current->version());
+        m_ui.descriptionView->setHtml(desc);
+    }
 }
 
 QString BackendChooseDialog::backendName()
