@@ -24,17 +24,17 @@ class KAlgebraBackend : public Cantor::Backend
 {
     Q_OBJECT
     public:
-        explicit KAlgebraBackend( QObject* parent = 0,const QList<QVariant> args = QList<QVariant>());
-        ~KAlgebraBackend();
+        explicit KAlgebraBackend( QObject* parent = nullptr, const QList<QVariant> args = QList<QVariant>());
+        ~KAlgebraBackend() override = default;
 
-	QString id() const Q_DECL_OVERRIDE;
-        Cantor::Session *createSession() Q_DECL_OVERRIDE;
-        Cantor::Backend::Capabilities capabilities() const Q_DECL_OVERRIDE;
+	QString id() const override;
+        Cantor::Session *createSession() override;
+        Cantor::Backend::Capabilities capabilities() const override;
 
-        QWidget* settingsWidget(QWidget* parent) const Q_DECL_OVERRIDE;
-        KConfigSkeleton* config() const Q_DECL_OVERRIDE;
+        QWidget* settingsWidget(QWidget* parent) const override;
+        KConfigSkeleton* config() const override;
 
-	QUrl helpUrl() const Q_DECL_OVERRIDE;
+	QUrl helpUrl() const override;
         QString version() const override;
 };
 
