@@ -27,11 +27,11 @@ class KAlgebraExpression : public Cantor::Expression
 {
     Q_OBJECT
     public:
-        KAlgebraExpression( KAlgebraSession* session);
-        ~KAlgebraExpression();
+        explicit KAlgebraExpression( KAlgebraSession* session, bool internal = false);
+        ~KAlgebraExpression() override = default;
 
-        void evaluate() Q_DECL_OVERRIDE;
-        void interrupt() Q_DECL_OVERRIDE;
+        void evaluate() override;
+        void interrupt() override;
 };
 
 #endif
