@@ -29,11 +29,11 @@ class NullExpression : public Cantor::Expression
 {
   Q_OBJECT
   public:
-    NullExpression( Cantor::Session* session);
-    ~NullExpression() override;
+    explicit NullExpression( Cantor::Session* session, bool internal = false);
+    ~NullExpression() override = default;
 
-    void evaluate() Q_DECL_OVERRIDE;
-    void interrupt() Q_DECL_OVERRIDE;
+    void evaluate() override;
+    void interrupt() override;
 
   public Q_SLOTS:
     void evalFinished();
