@@ -48,12 +48,8 @@ class OctaveSession : public Cantor::Session
         Cantor::CompletionObject* completionFor(const QString& cmd, int index=-1) override;
         Cantor::SyntaxHelpObject* syntaxHelpFor(const QString& cmd) override;
         QSyntaxHighlighter* syntaxHighlighter(QObject* parent) override;
-        QAbstractItemModel* variableModel() override;
         void runFirstExpression() override;
 
-    Q_SIGNALS:
-        void variablesChanged();
-
     private:
         const static QRegExp PROMPT_UNCHANGEABLE_COMMAND;
 
@@ -66,13 +62,10 @@ class OctaveSession : public Cantor::Session
 
         KDirWatch* m_watch;
         QString m_tempDir;
-        bool m_loginFinish;
         bool m_syntaxError;
 
         QString m_output;
 
-        Cantor::DefaultVariableModel* m_variableModel;
-
     private:
         void readFromOctave(QByteArray data);
         bool isDoNothingCommand(const QString& command);
