@@ -46,9 +46,28 @@ QString Python3Backend::version() const
     return QLatin1String("3.6");
 }
 
+Cantor::Backend::Capabilities Python3Backend::capabilities() const
+{
+    qDebug()<<"Requesting capabilities of Python3Session";
+
+    Backend::Capabilities cap =
+        Cantor::Backend::SyntaxHighlighting |
+        Cantor::Backend::Completion         |
+        Cantor::Backend::SyntaxHelp;
+
+    if(PythonSettings::variableManagement())
+        cap |= Cantor::Backend::VariableManagement;
+
+    return cap;
+}
+
 QUrl Python3Backend::helpUrl() const
 {
-    return QUrl(i18nc("the url to the documentation Python 3", "http://docs.python.org/3/"));
+    const QUrl& localDoc = PythonSettings::self()->localDoc();
+    if (!localDoc.isEmpty())
+        return localDoc;
+    else
+        return QUrl(i18nc("the url to the documentation Python 3", "http://docs.python.org/3/"));
 }
 
 QString Python3Backend::description() const
