@@ -17,10 +17,11 @@
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/
 
+#include "qalculatebackend.h"
+
 #include "ui_settings.h"
 
 #include "settings.h"
-#include "qalculatebackend.h"
 #include "qalculatesession.h"
 #include "qalculateextensions.h"
 
@@ -42,16 +43,16 @@ QalculateBackend::QalculateBackend( QObject* parent,const QList<QVariant> args )
     new QalculatePlotExtension(this);
 }
 
-QalculateBackend::~QalculateBackend()
-{
-
-}
-
 QString QalculateBackend::id() const
 {
     return QLatin1String("qalculate");
 }
 
+QString QalculateBackend::version() const
+{
+    return QLatin1String("0.9");
+}
+
 Cantor::Session* QalculateBackend::createSession()
 {
     return new QalculateSession(this);
