@@ -32,7 +32,7 @@ class EpsRenderer
 {
   public:
     EpsRenderer();
-    ~EpsRenderer();
+    ~EpsRenderer() = default;
 
     enum FormulaProperties {CantorFormula = 1, ImagePath = 2, Code = 3,
                             Delimiter = 4};
