@@ -48,12 +48,12 @@ EpsResult::~EpsResult()
 
 QString EpsResult::toHtml()
 {
-    return QString::fromLatin1("<img src=\"%1\" />").arg(d->url.url());
+    return QStringLiteral("<img src=\"%1\" />").arg(d->url.url());
 }
 
 QString EpsResult::toLatex()
 {
-    return QString::fromLatin1(" \\begin{center} \n \\includegraphics[width=12cm]{%1}\n \\end{center}").arg(d->url.fileName());
+    return QStringLiteral(" \\begin{center} \n \\includegraphics[width=12cm]{%1}\n \\end{center}").arg(d->url.fileName());
 }
 
 QVariant EpsResult::data()
@@ -73,15 +73,15 @@ int EpsResult::type()
 
 QString EpsResult::mimeType()
 {
-    return QLatin1String("image/x-eps");
+    return QStringLiteral("image/x-eps");
 }
 
 QDomElement EpsResult::toXml(QDomDocument& doc)
 {
     qDebug()<<"saving imageresult "<<toHtml();
-    QDomElement e=doc.createElement(QLatin1String("Result"));
-    e.setAttribute(QLatin1String("type"), QLatin1String("image"));
-    e.setAttribute(QLatin1String("filename"), d->url.fileName());
+    QDomElement e=doc.createElement(QStringLiteral("Result"));
+    e.setAttribute(QStringLiteral("type"), QStringLiteral("image"));
+    e.setAttribute(QStringLiteral("filename"), d->url.fileName());
     qDebug()<<"done";
 
     return e;
