@@ -57,7 +57,7 @@ QWidget* PanelPlugin::parentWidget()
 void PanelPlugin::setPluginInfo(const KPluginMetaData& info)
 {
     d->name=info.name();
-    d->requiredExtensions=info.value(QLatin1String("RequiredExtensions")).split(QLatin1Char(','));
+    d->requiredExtensions=info.value(QStringLiteral("RequiredExtensions")).split(QLatin1Char(','));
 }
 
 QStringList PanelPlugin::requiredExtensions()
