@@ -38,10 +38,6 @@ TextEntry::TextEntry(Worksheet* worksheet) : WorksheetEntry(worksheet), m_textIt
     connect(m_textItem, &WorksheetTextItem::doubleClick, this, &TextEntry::resolveImagesAtCursor);
 }
 
-TextEntry::~TextEntry()
-{
-}
-
 void TextEntry::populateMenu(QMenu* menu, QPointF pos)
 {
     bool imageSelected = false;
@@ -153,7 +149,7 @@ QString TextEntry::toPlain(const QString& commandSep, const QString& commentStar
     if (commentStartingSeq.isEmpty())
         return QString();
     /*
-    // whould this be plain enough?
+    // would this be plain enough?
     QTextCursor cursor = m_textItem->textCursor();
     cursor.movePosition(QTextCursor::Start);
     cursor.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
